@@ -4,7 +4,7 @@ from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils import timezone
 from django.db.models import get_model
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 from django.utils.encoding import python_2_unicode_compatible
 from django.core.exceptions import ImproperlyConfigured
 
@@ -42,13 +42,11 @@ class AbstractApplication(models.Model):
         (CLIENT_PUBLIC, _('Public')),
     )
 
-    GRANT_ALLINONE = 'all-in-one'
     GRANT_AUTHORIZATION_CODE = 'authorization-code'
     GRANT_IMPLICIT = 'implicit'
     GRANT_PASSWORD = 'password'
     GRANT_CLIENT_CREDENTIALS = 'client-credentials'
     GRANT_TYPES = (
-        (GRANT_ALLINONE, _('All-in-one generic')),
         (GRANT_AUTHORIZATION_CODE, _('Authorization code')),
         (GRANT_IMPLICIT, _('Implicit')),
         (GRANT_PASSWORD, _('Resource owner password-based')),
@@ -96,10 +94,9 @@ class AbstractApplication(models.Model):
         from django.core.exceptions import ValidationError
         if not self.redirect_uris \
             and self.authorization_grant_type \
-            in (AbstractApplication.GRANT_ALLINONE,
-                AbstractApplication.GRANT_AUTHORIZATION_CODE,
+            in (AbstractApplication.GRANT_AUTHORIZATION_CODE,
                 AbstractApplication.GRANT_IMPLICIT):
-            error = _('Redirect_uris could not be empty with {} grant_type')
+            error = _('Redirect_uris could not be empty with {0} grant_type')
             raise ValidationError(error.format(self.authorization_grant_type))
 
     def get_absolute_url(self):
@@ -235,6 +232,6 @@ def get_application_model():
         raise ImproperlyConfigured(e)
     app_model = get_model(app_label, model_name)
     if app_model is None:
-        e = "APPLICATION_MODEL refers to model {} that has not been installed"
+        e = "APPLICATION_MODEL refers to model {0} that has not been installed"
         raise ImproperlyConfigured(e.format(oauth2_settings.APPLICATION_MODEL))
     return app_model
