@@ -2,13 +2,14 @@ from __future__ import unicode_literals
 
 import base64
 import json
+import datetime
 
 from django.test import TestCase, RequestFactory
 from django.core.urlresolvers import reverse
 from django.utils import timezone
 
 from ..compat import urlparse, parse_qs, urlencode, get_user_model
-from ..models import get_application_model, Grant
+from ..models import get_application_model, Grant, AccessToken
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
@@ -91,6 +92,32 @@ class TestAuthorizationCodeView(BaseTest):
         self.assertEqual(form['scopes'].value(), "read write")
         self.assertEqual(form['client_id'].value(), self.application.client_id)
 
+    def test_pre_auth_approval_prompt(self):
+        """
+
+        """
+        tok = AccessToken.objects.create(user=self.test_user, token='1234567890',
+                                         application=self.application,
+                                         expires=timezone.now()+datetime.timedelta(days=1),
+                                         scope='read write')
+        self.client.login(username="test_user", password="123456")
+        query_string = urlencode({
+            'client_id': self.application.client_id,
+            'response_type': 'code',
+            'state': 'random_state_string',
+            'scope': 'read write',
+            'redirect_uri': 'http://example.it',
+            'approval_prompt': 'auto',
+        })
+        url = "{url}?{qs}".format(url=reverse('oauth2_provider:authorize'), qs=query_string)
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 302)
+        # user already authorized the application, but with different scopes: prompt them.
+        tok.scope = 'read'
+        tok.save()
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+
     def test_pre_auth_default_redirect(self):
         """
         Test for default redirect uri if omitted from query string with response_type: code
@@ -277,6 +304,15 @@ class TestAuthorizationCodeTokenView(BaseTest):
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('refresh_token' in content)
 
+        # make a second token request to be sure the previous refresh token remains valid, see #65
+        authorization_code = self.get_auth()
+        token_request_data = {
+            'grant_type': 'authorization_code',
+            'code': authorization_code,
+            'redirect_uri': 'http://example.it'
+        }
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
+
         token_request_data = {
             'grant_type': 'refresh_token',
             'refresh_token': content['refresh_token'],
@@ -288,6 +324,12 @@ class TestAuthorizationCodeTokenView(BaseTest):
         content = json.loads(response.content.decode("utf-8"))
         self.assertTrue('access_token' in content)
 
+        # check refresh token cannot be used twice
+        response = self.client.post(reverse('oauth2_provider:token'), data=token_request_data, **auth_headers)
+        self.assertEqual(response.status_code, 400)
+        content = json.loads(response.content.decode("utf-8"))
+        self.assertTrue('invalid_grant' in content.values())
+
     def test_refresh_no_scopes(self):
         """
         Request an access token using a refresh token without passing any scope
