@@ -2,6 +2,7 @@ import logging
 
 from django.http import HttpResponse, HttpResponseRedirect
 from django.views.generic import View, FormView
+from django.utils import timezone
 
 from oauthlib.oauth2 import Server
 
@@ -11,7 +12,6 @@ from ..settings import oauth2_settings
 from ..exceptions import OAuthToolkitError
 from ..forms import AllowForm
 from ..models import get_application_model
-from ..oauth2_validators import OAuth2Validator
 from .mixins import OAuthLibMixin
 
 Application = get_application_model()
@@ -67,7 +67,7 @@ class AuthorizationView(BaseAuthorizationView, FormView):
     form_class = AllowForm
 
     server_class = Server
-    validator_class = OAuth2Validator
+    validator_class = oauth2_settings.OAUTH2_VALIDATOR_CLASS
 
     def get_initial(self):
         # TODO: move this scopes conversion from and to string into a utils function
@@ -110,9 +110,24 @@ class AuthorizationView(BaseAuthorizationView, FormView):
             kwargs['application'] = Application.objects.get(client_id=credentials['client_id'])  # TODO: cache it!
             kwargs.update(credentials)
             self.oauth2_data = kwargs
-            # following code is here only because of https://code.djangoproject.com/ticket/17795
+            # following two loc are here only because of https://code.djangoproject.com/ticket/17795
             form = self.get_form(self.get_form_class())
             kwargs['form'] = form
+
+            # Check to see if the user has already granted access and return
+            # a successful response depending on 'approval_prompt' url parameter
+            require_approval = request.GET.get('approval_prompt', 'force')
+            if require_approval == 'auto':
+                tokens = request.user.accesstoken_set.filter(application=kwargs['application'],
+                                                             expires__gt=timezone.now()).all()
+                # check past authorizations regarded the same scopes as the current one
+                for token in tokens:
+                    if token.allow_scopes(scopes):
+                        uri, headers, body, status = self.create_authorization_response(
+                            request=self.request, scopes=" ".join(scopes),
+                            credentials=credentials, allow=True)
+                        return HttpResponseRedirect(uri)
+
             return self.render_to_response(self.get_context_data(**kwargs))
 
         except OAuthToolkitError as error:
@@ -123,13 +138,13 @@ class TokenView(CsrfExemptMixin, OAuthLibMixin, View):
     """
     Implements an endpoint to provide access tokens
 
-    The endpoint is used in the followin flows:
+    The endpoint is used in the following flows:
      * Authorization code
      * Password
      * Client credentials
     """
     server_class = Server
-    validator_class = OAuth2Validator
+    validator_class = oauth2_settings.OAUTH2_VALIDATOR_CLASS
 
     def post(self, request, *args, **kwargs):
         url, headers, body, status = self.create_token_response(request)
